@@ -4,6 +4,5 @@ pub use crate::backend::*;
 pub use crate::config::*;
 pub use crate::fps_plugin::FpsPlugin;
 pub use crate::graphics::Graphics;
-pub use crate::keyboard;
-pub use crate::mouse;
+pub use crate::input::*;
 pub use crate::plugins::{Plugin, Plugins};
